@@ -1,16 +1,14 @@
 """Module for parsing and representing calendar dates in gedcom format.
 """
 
-from __future__ import print_function, absolute_import, division
-
 __all__ = [
-    "CalendarTypes", "CalendarDate", "FrenchDate", "GregorianDate",
+    "CalendarType", "CalendarDate", "FrenchDate", "GregorianDate",
     "HebrewDate", "JulianDate", "CalendarDateVisitor",
 ]
 
 import abc
+import enum
 import re
-from six import with_metaclass
 
 import convertdate.french_republican
 import convertdate.gregorian
@@ -46,7 +44,8 @@ DATE = r"""
 DATE_RE = re.compile("^" + DATE + "$", re.X | re.I)
 
 
-class CalendarTypes(object):
+@enum.unique
+class CalendarType(enum.Enum):
     """Namespace for constants defining names of calendars.
 
     Note that it does not define constants for ``ROMAN`` calendar which is
@@ -54,41 +53,50 @@ class CalendarTypes(object):
     ``UNKNOWN`` calendar which is not supported by this library.
 
     The constants defined in this namespace are used for the values of the
-    :attr:`CalendarDate.calendar` attribute. Each separate class implementing
-    :class:`CalendarDate` interface uses distinct value for that attribute,
+    `CalendarDate.calendar` attribute. Each separate class implementing
+    `CalendarDate` interface uses distinct value for that attribute,
     and this value can be used to deduce actual type of the
-    :class:`CalendarDate` instance.
+    `CalendarDate` instance.
     """
 
     GREGORIAN = "GREGORIAN"
-    """This is the value assigned to :attr:`GregorianDate.calendar` attribute.
+    """This is the value assigned to `GregorianDate.calendar` attribute.
     """
 
     JULIAN = "JULIAN"
-    """This is the value assigned to :attr:`JulianDate.calendar` attribute.
+    """This is the value assigned to `JulianDate.calendar` attribute.
     """
 
     HEBREW = "HEBREW"
-    """This is the value assigned to :attr:`HebrewDate.calendar` attribute.
+    """This is the value assigned to `HebrewDate.calendar` attribute.
     """
 
     FRENCH_R = "FRENCH R"
-    """This is the value assigned to :attr:`FrenchDate.calendar` attribute.
+    """This is the value assigned to `FrenchDate.calendar` attribute.
     """
 
 
-class CalendarDate(with_metaclass(abc.ABCMeta)):
+class CalendarDate(metaclass=abc.ABCMeta):
     """Interface for calendar date representation.
 
-    :param int year: Calendar year number. If ``bc`` parameter is ``True``
-        then this year is before "epoch" of that calendar.
-    :param str month: Name of the month. Optional, but if day is given then
-        month cannot be None.
-    :param int day: Day in a month, optional.
-    :param bool bc: `True` if year has "B.C."
-    :param str original: Original string representation of this date as it was
-        specified in GEDCOM file, could be ``None``.
+    Parameters
+    ----------
+    year : `int`
+        Calendar year number. If ``bc`` parameter is ``True`` then this year
+        is before "epoch" of that calendar.
+    month : `str`
+        Name of the month. Optional, but if day is given then month cannot be
+        None.
+    day : `int`
+        Day in a month, optional.
+    bc : `bool`
+        ``True`` if year has "B.C."
+    original : `str`
+        Original string representation of this date as it was specified in
+        GEDCOM file, could be ``None``.
 
+    Notes
+    -----
     This class defines attributes and methods that are common for all
     calendars defined in GEDCOM (though the meaning and representation can be
     different in different calendars). In GEDCOM date consists of year, month,
@@ -99,25 +107,25 @@ class CalendarDate(with_metaclass(abc.ABCMeta)):
 
     Implementation for different calendars are provided by subclasses which
     can implement additional attributes or methods. All subclasses need to
-    implement :meth:`key` method to support ordering of the dates from
+    implement `key()` method to support ordering of the dates from
     different calendars. There are presently four implementations defined
     in this module:
 
-        - :class:`GregorianDate` for "GREGORIAN" calendar
-        - :class:`JulianDate` for "JULIAN" calendar
-        - :class:`HebrewDate` for "HEBREW" calendar
-        - :class:`FrenchDate` for "FRENCH R" calendar
+        - `GregorianDate` for "GREGORIAN" calendar
+        - `JulianDate` for "JULIAN" calendar
+        - `HebrewDate` for "HEBREW" calendar
+        - `FrenchDate` for "FRENCH R" calendar
 
     To implement type-specific code on client side one can use one of these
     approaches:
 
-        - dispatch based on the value of :attr:`calendar` attribute, it has
-          one of the values defined in :class:`CalendarTypes` namespace,
+        - dispatch based on the value of `calendar` attribute, it has
+          one of the values defined in `CalendarType` enum,
           the value maps uniquely to an implementation class;
         - dispatch based on the type of the instance using ``isinstance``
           method to check the type (e.g. ``isinstance(date, GregorianDate)``);
         - double dispatch (visitor pattern) by implementing
-          :class:`CalendarDateVisitor` interface.
+          `CalendarDateVisitor` interface.
     """
 
     def __init__(self, year, month=None, day=None, bc=False, original=None):
@@ -178,8 +186,8 @@ class CalendarDate(with_metaclass(abc.ABCMeta)):
     @property
     @abc.abstractmethod
     def calendar(self):
-        """Calendar name used for this date, one of the constants defined in
-        :class:`CalendarTypes` (`str`)
+        """Calendar used for this date, one of the `CalendarType` enums
+        (`CalendarType`)
         """
         raise NotImplementedError()
 
@@ -190,18 +198,36 @@ class CalendarDate(with_metaclass(abc.ABCMeta)):
         Each concrete sub-class will implement this method by dispatching the
         call to corresponding visitor method.
 
-        :param CalendarDateVisitor visitor: visitor instance.
-        :returns: Value returned from a visitor method.
+        Parameters
+        ----------
+        visitor : `CalendarDateVisitor`
+            Visitor instance.
+
+        Returns
+        -------
+        value : `object`
+            Value returned from a visitor method.
         """
         raise NotImplementedError()
 
     @classmethod
     def parse(cls, datestr):
-        """Parse <DATE> string and make :class:`CalendarDate` from it.
+        """Parse ``<DATE>`` string and make `CalendarDate` from it.
 
-        :param str datestr: String with GEDCOM date.
-        :returns: :class:`CalendarDate` instance
-        :raises: ValueError is raised if parsing fails.
+        Parameters
+        ----------
+        datestr : `str`
+            String with GEDCOM date.
+
+        Returns
+        -------
+        date : `CalendarDate`
+            Date instance.
+
+        Raises
+        ------
+        ValueError
+            Raised if parsing fails.
         """
 
         def _dual_year(year_str, dual_year_str):
@@ -227,22 +253,26 @@ class CalendarDate(with_metaclass(abc.ABCMeta)):
         if m is None:
             raise ValueError("Failed to parse date: " + datestr)
 
-        calendar = m.group(1) or CalendarTypes.GREGORIAN
+        calendar = m.group(1) or "GREGORIAN"
+        try:
+            calendar = CalendarType(calendar)
+        except ValueError:
+            raise ValueError("Unknown calendar: " + datestr)
         day = None if m.group(2) is None else int(m.group(2))
         month = m.group(3)
         year = int(m.group(4))
         dual_year = _dual_year(m.group(4), m.group(5))
         bc = m.group(6) is not None
-        if dual_year is not None and calendar != CalendarTypes.GREGORIAN:
+        if dual_year is not None and calendar != CalendarType.GREGORIAN:
             raise ValueError("Cannot use dual year (YYYY/YY) in non-Gregorian calendar: " + datestr)
 
-        if calendar == CalendarTypes.GREGORIAN:
+        if calendar == CalendarType.GREGORIAN:
             return GregorianDate(year, month, day, bc=bc, original=datestr, dual_year=dual_year)
-        elif calendar == CalendarTypes.JULIAN:
+        elif calendar == CalendarType.JULIAN:
             return JulianDate(year, month, day, bc=bc, original=datestr)
-        elif calendar == CalendarTypes.FRENCH_R:
+        elif calendar == CalendarType.FRENCH_R:
             return FrenchDate(year, month, day, bc=bc, original=datestr)
-        elif calendar == CalendarTypes.HEBREW:
+        elif calendar == CalendarType.HEBREW:
             return HebrewDate(year, month, day, bc=bc, original=datestr)
         else:
             raise ValueError("Unknown calendar: " + datestr)
@@ -272,8 +302,8 @@ class CalendarDate(with_metaclass(abc.ABCMeta)):
         """Make printable representation out of this instance.
         """
         val = [self.day, self.month, self.year_str]
-        if self.calendar != CalendarTypes.GREGORIAN:
-            val = ["@#D{}@".format(self.calendar)] + val
+        if self.calendar != CalendarType.GREGORIAN:
+            val = ["@#D{}@".format(self.calendar.value)] + val
         return " ".join([str(item) for item in val if item is not None])
 
     def __repr__(self):
@@ -281,15 +311,20 @@ class CalendarDate(with_metaclass(abc.ABCMeta)):
 
 
 class GregorianDate(CalendarDate):
-    """Implementation of :class:`CalendarDate` for Gregorian calendar.
+    """Implementation of `CalendarDate` for Gregorian calendar.
 
     Parameter ``dual_year`` (and corresponding attribute) is used for dual
-    year. Other parameters have the same meaning as in :class:`CalendarDate`
+    year. Other parameters have the same meaning as in `CalendarDate`
     class.
 
-    :param int dual_year: Dual year number or ``None``. Actual year should be
-        given, not just two last digits.
+    Parameters
+    ----------
+    dual_year : `int`, optional
+        Dual year number or ``None``. Actual year should be given, not just
+        two last digits.
 
+    Notes
+    -----
     In GEDCOM Gregorian calendar dates are allowed to specify year in the
     form YEAR1/YEAR2 (a.k.a.) dual-dating. Second number is used to specify
     year as if calendar year starts in January, while the first number is
@@ -313,14 +348,14 @@ class GregorianDate(CalendarDate):
 
     @property
     def calendar(self):
-        """Calendar name used for this date, for GregorianDate this is always
-        :attr:`CalendarTypes.GREGORIAN` (`str`)
-        """
-        return CalendarTypes.GREGORIAN
+        # docstring inherited from base class
+        return CalendarType.GREGORIAN
 
     def key(self):
         """Return ordering key for this instance.
         """
+        calendar = convertdate.gregorian
+
         # In dual dating use second year
         year = self.dual_year if self.dual_year is not None else self.year
         if self.bc:
@@ -341,7 +376,22 @@ class GregorianDate(CalendarDate):
                 year += 1
             day = 1
             offset = 1.
-        jd = convertdate.gregorian.to_jd(year, month, day) - offset
+
+        dates = [
+            (year, month, day, offset),
+            (year, month + 1, 1, 1.),
+            (year + 1, 1, 1, 1.),
+        ]
+        for year, month, day, offset in dates:
+            try:
+                jd = calendar.to_jd(year, month, day) - offset
+                break
+            except ValueError:
+                # Likely a non-existing date, use another
+                pass
+        else:
+            # nothing works, use arbitrary date in the future
+            jd = 2816787.5
 
         flag = 1 if self.day is None or self.month_num is None else 0
         return jd, flag
@@ -369,9 +419,9 @@ class GregorianDate(CalendarDate):
 
 
 class JulianDate(CalendarDate):
-    """Implementation of :class:`CalendarDate` for Julian calendar.
+    """Implementation of `CalendarDate` for Julian calendar.
 
-    All parameters have the same meaning as in :class:`CalendarDate` class.
+    All parameters have the same meaning as in `CalendarDate` class.
     """
     def __init__(self, year, month=None, day=None, bc=False, original=None):
         CalendarDate.__init__(self, year, month, day, bc, original)
@@ -385,6 +435,8 @@ class JulianDate(CalendarDate):
     def key(self):
         """Return ordering key for this instance.
         """
+        calendar = convertdate.julian
+
         year = - self.year if self.bc else self.year
         month = self.month_num
         day = self.day
@@ -402,26 +454,39 @@ class JulianDate(CalendarDate):
                 year += 1
             day = 1
             offset = 1.
-        jd = convertdate.julian.to_jd(year, month, day) - offset
+
+        dates = [
+            (year, month, day, offset),
+            (year, month + 1, 1, 1.),
+            (year + 1, 1, 1, 1.),
+        ]
+        for year, month, day, offset in dates:
+            try:
+                jd = calendar.to_jd(year, month, day) - offset
+                break
+            except ValueError:
+                # Likely a non-existing date, use another
+                pass
+        else:
+            # nothing works, use arbitrary date in the future
+            jd = 2816787.5
 
         flag = 1 if self.day is None or self.month_num is None else 0
         return jd, flag
 
     @property
     def calendar(self):
-        """Calendar name used for this date, for JulianDate this is always
-        :attr:`CalendarTypes.JULIAN` (`str`)
-        """
-        return CalendarTypes.JULIAN
+        # docstring inherited from base class
+        return CalendarType.JULIAN
 
     def accept(self, visitor):
         return visitor.visitJulian(self)
 
 
 class HebrewDate(CalendarDate):
-    """Implementation of :class:`CalendarDate` for Hebrew calendar.
+    """Implementation of `CalendarDate` for Hebrew calendar.
 
-    All parameters have the same meaning as in :class:`CalendarDate` class.
+    All parameters have the same meaning as in `CalendarDate` class.
     """
     def __init__(self, year, month=None, day=None, bc=False, original=None):
         CalendarDate.__init__(self, year, month, day, bc, original)
@@ -437,27 +502,41 @@ class HebrewDate(CalendarDate):
         """
         calendar = convertdate.hebrew
         year = - self.year if self.bc else self.year
-        month = self.month_num or convertdate.hebrew.year_months(year)
+        month = self.month_num or calendar.year_months(year)
         day = self.day if self.day is not None else calendar.month_days(year, month)
-        jd = calendar.to_jd(year, month, day)
+
+        dates = [
+            (year, month, day, 0.),
+            (year, month + 1, 1, 1.),
+            (year + 1, 1, 1, 1.),
+        ]
+        for year, month, day, offset in dates:
+            try:
+                jd = calendar.to_jd(year, month, day) - offset
+                break
+            except ValueError:
+                # Likely a non-existing date, use another
+                pass
+        else:
+            # nothing works, use arbitrary date in the future
+            jd = 2816787.5
+
         flag = 1 if self.day is None or self.month_num is None else 0
         return jd, flag
 
     @property
     def calendar(self):
-        """Calendar name used for this date, for HebrewDate this is always
-        :attr:`CalendarTypes.HEBREW` (`str`)
-        """
-        return CalendarTypes.HEBREW
+        # docstring inherited from base class
+        return CalendarType.HEBREW
 
     def accept(self, visitor):
         return visitor.visitHebrew(self)
 
 
 class FrenchDate(CalendarDate):
-    """Implementation of :class:`CalendarDate` for French Republican calendar.
+    """Implementation of `CalendarDate` for French Republican calendar.
 
-    All parameters have the same meaning as in :class:`CalendarDate` class.
+    All parameters have the same meaning as in `CalendarDate` class.
     """
     def __init__(self, year, month=None, day=None, bc=False, original=None):
         CalendarDate.__init__(self, year, month, day, bc, original)
@@ -481,29 +560,43 @@ class FrenchDate(CalendarDate):
                 day = 5
             else:
                 day = 30
-        jd = calendar.to_jd(year, month, day)
+
+        dates = [
+            (year, month, day, 0.),
+            (year, month + 1, 1, 1.),
+            (year + 1, 1, 1, 1.),
+        ]
+        for year, month, day, offset in dates:
+            try:
+                jd = calendar.to_jd(year, month, day) - offset
+                break
+            except ValueError:
+                # Likely a non-existing date, use another
+                pass
+        else:
+            # nothing works, use arbitrary date in the future
+            jd = 2816787.5
+
         flag = 1 if self.day is None or self.month_num is None else 0
         return jd, flag
 
     @property
     def calendar(self):
-        """Calendar name used for this date, for FrenchDate this is always
-        :attr:`CalendarTypes.FRENCH` (`str`)
-        """
-        return CalendarTypes.FRENCH_R
+        # docstring inherited from base class
+        return CalendarType.FRENCH_R
 
     def accept(self, visitor):
         return visitor.visitFrench(self)
 
 
-class CalendarDateVisitor(with_metaclass(abc.ABCMeta)):
+class CalendarDateVisitor(metaclass=abc.ABCMeta):
     """Interface for implementation of Visitor pattern for
-    :class:`CalendarDate` classes.
+    `CalendarDate` classes.
 
-    One can easily extend behavior of the :class:`CalendarDate` class
+    One can easily extend behavior of the `CalendarDate` class
     hierarchy without modifying classes themselves. Clients need to implement
-    new behavior by sub-classing :class:`CalendarDateVisitor` and calling
-    :meth:`CalendarDate.accept()` method, e.g.::
+    new behavior by sub-classing `CalendarDateVisitor` and calling
+    `CalendarDate.accept()` method, e.g.::
 
         class FormatterVisitor(CalendarDateVisitor):
 
@@ -518,22 +611,70 @@ class CalendarDateVisitor(with_metaclass(abc.ABCMeta)):
         formatted = date.accept(visitor)
     """
 
+    @abc.abstractmethod
     def visitGregorian(self, date):
-        """Visit an instance of :class:`GregorianDate` type.
+        """Visit an instance of `GregorianDate` type.
+
+        Parameters
+        ----------
+        date : `GregorianDate`
+            Date instance.
+
+        Returns
+        -------
+        value : `object`
+            Implementation of this method can return anything, value will be
+            returned from `CalendarDate.accept()` method.
         """
         raise NotImplementedError()
 
+    @abc.abstractmethod
     def visitJulian(self, date):
-        """Visit an instance of :class:`JulianDate` type.
+        """Visit an instance of `JulianDate` type.
+
+        Parameters
+        ----------
+        date : `JulianDate`
+            Date instance.
+
+        Returns
+        -------
+        value : `object`
+            Implementation of this method can return anything, value will be
+            returned from `CalendarDate.accept()` method.
         """
         raise NotImplementedError()
 
+    @abc.abstractmethod
     def visitHebrew(self, date):
-        """Visit an instance of :class:`HebrewDate` type.
+        """Visit an instance of `HebrewDate` type.
+
+        Parameters
+        ----------
+        date : `HebrewDate`
+            Date instance.
+
+        Returns
+        -------
+        value : `object`
+            Implementation of this method can return anything, value will be
+            returned from `CalendarDate.accept()` method.
         """
         raise NotImplementedError()
 
+    @abc.abstractmethod
     def visitFrench(self, date):
-        """Visit an instance of :class:`FrenchDate` type.
+        """Visit an instance of `FrenchDate` type.
+
+        Parameters
+        ----------
+        date : `FrenchDate`
+            Date instance.
+
+        Returns
+        -------
+        value : `object`
+            Implementation of this method can return anything, value will be
+            returned from `CalendarDate.accept()` method.
         """
         raise NotImplementedError()
