@@ -3,36 +3,57 @@
 """Module containing Python in-memory model for GEDCOM data.
 """
 
-from __future__ import print_function, absolute_import, division
-
 __all__ = ['make_record', 'Record', 'Pointer', 'NameRec', 'Name',
            'Date', 'Individual']
 
+import enum
+
 from .detail.name import (split_name, parse_name_altree, parse_name_ancestris,
                           parse_name_myher)
 from .date import DateValue
 
-# Even though the structure of GEDCOM file is more or less fixed,
-# interpretation of some data may vary depending on which application
-# produced GEDCOM file. Constants define different known dialect which
-# are handled by classes below.
-DIALECT_DEFAULT = "DEF"
-DIALECT_MYHERITAGE = "MYHER"  # myheritage.com
-DIALECT_ALTREE = "AGELONG"  # Agelong Tree (genery.com)
-DIALECT_ANCESTRIS = "ANCESTRIS"  # Ancestris (ancestris.org)
 
-# Names/Individuals can be ordered differently, e.g. by surname first,
-# by given name first, or by maiden name first. This few constants define
-# different ordering options.
-ORDER_SURNAME_GIVEN = "last+first"
-ORDER_GIVEN_SURNAME = "first+last"
-ORDER_MAIDEN_GIVEN = "maiden+first"  # uses last name if no maiden name
-ORDER_GIVEN_MAIDEN = "first+maiden"  # uses last name if no maiden name
-ORDER_LIST = [ORDER_SURNAME_GIVEN, ORDER_GIVEN_SURNAME,
-              ORDER_MAIDEN_GIVEN, ORDER_GIVEN_MAIDEN]
+@enum.unique
+class Dialect(enum.Enum):
+    """Even though the structure of GEDCOM file is more or less fixed,
+    interpretation of some data may vary depending on which application
+    produced GEDCOM file. Constants define different known dialect which
+    are handled by classes below.
+    """
+
+    DEFAULT = "DEF"
+    """Constant used for default dialect (`str`)."""
+
+    MYHERITAGE = "MYHER"  # myheritage.com
+    """Constant used for myheritage.com dialect (`str`)."""
+
+    ALTREE = "AGELONG"  # Agelong Tree (genery.com)
+    """Constant used for genery.com dialect (`str`)."""
+
+    ANCESTRIS = "ANCESTRIS"  # Ancestris (ancestris.org)
+    """Constant used for ancestris.org dialect (`str`)."""
 
 
-class Record(object):
+@enum.unique
+class NameOrder(enum.Enum):
+    """Names/Individuals can be ordered differently, e.g. by surname first,
+    by given name first, or by maiden name first. This few constants define
+    different ordering options.
+    """
+    SURNAME_GIVEN = "last+first"
+    """Order by surname first, given name second."""
+
+    GIVEN_SURNAME = "first+last"
+    """Order by given name first, surname second."""
+
+    MAIDEN_GIVEN = "maiden+first"
+    """Order by maiden name (or surname) first, given name second."""
+
+    GIVEN_MAIDEN = "first+maiden"
+    """Order by given name first, maiden name (or surname) second."""
+
+
+class Record:
     """Class representing a parsed GEDCOM record in a generic format.
 
     This is the main element of the data model, it represents records in
@@ -52,15 +73,15 @@ class Record(object):
 
     - ``sub_records`` attribute contains the list of all immediate subordinate
       records of this record.
-    - :py:meth:`sub_tag` method find subordinate record given its tag, it can
+    - `sub_tag` method find subordinate record given its tag, it can
       do it recursively if tag name contains multiple levels separated by
       slashes, and it can navigate through the pointer records transparently
       if ``follow`` argument is ``True``.
-    - :py:meth:`sub_tag_value` is a convenience method that finds a
-      subordinate record (via :py:meth:`~Record.sub_tag` call) but returns
+    - `sub_tag_value` is a convenience method that finds a
+      subordinate record (via `~Record.sub_tag` call) but returns
       value of the record instead of record itself. This simplifies handling
       of missing tags.
-    - :py:meth:`sub_tags` returns the list of immediate subordinate records
+    - `sub_tags` returns the list of immediate subordinate records
       (no recursion). It is useful when multiple sub-records with the same tag
       can exist.
 
@@ -73,19 +94,28 @@ class Record(object):
     class is explicitly marked as non-hashable.
 
     Client code usually does not need to create instances of this class
-    directly, :py:meth:`make_record` should be used instead. If you create
+    directly, `make_record()` should be used instead. If you create
     an instance of this class (or its subclass) then you are responsible for
     filling its attributes.
 
-    :ivar int level: Record level number
-    :ivar str xref_id: Record reference ID, possibly empty.
-    :ivar str tag: Tag name
-    :ivar object value: Record value, possibly None, for many record types
-        value is a string or None, some subclasses can define different type
-        of record value.
-    :ivar list sub_records: List of subordinate records, possibly empty
-    :ivar int offset: Record location in a file
-    :ivar dialect: GEDCOM source dialect, one of the DIALECT_* values
+    Attributes
+    ----------
+    level : `int`
+        Record level number
+    xref_id : `str`
+        Record reference ID, possibly empty.
+    tag : `str`
+        Tag name
+    value : `object`
+        Record value, possibly ``None``, for many record types value is a
+        string or ``None``, some subclasses can define different type of
+        record value.
+    sub_records : `list` [ `Record` ]
+        List of subordinate records, possibly empty.
+    offset : `int`
+        Record location in a file.
+    dialect: `Dialect`
+        GEDCOM source dialect, one of the `Dialect` enums.
     """
     def __init__(self):
         self.level = None
@@ -99,7 +129,13 @@ class Record(object):
     def freeze(self):
         """Method called by parser when updates to this record finish.
 
-        :return: self
+        Some sub-classes will override this method to implement conversion
+        of record data to different representation.
+
+        Returns
+        -------
+        self : `Record`
+            Finalized record instance.
         """
         return self
 
@@ -115,52 +151,83 @@ class Record(object):
         record is used instead of pointer record, this also works for all
         intermediate records in a path.
 
-        :param str path: One or more tag names separated by slashes.
-        :param boolean follow: If True then resolve pointers.
-        :return: :py:class:`Record` instance or ``None`` if sub-record with a
-            given tag does not exist.
+        Parameters
+        ----------
+        path : `str`
+            One or more tag names separated by slashes.
+        follow : `bool`
+            If True then resolve pointers.
+
+        Returns
+        -------
+        record : `Record`
+            Subordinate record or ``None`` if sub-record with a given tag does
+            not exist.
         """
-        tags = path.split('/')
-        rec = self
-        for tag in tags:
-            recs = [x for x in (rec.sub_records or []) if x.tag == tag]
-            if not recs:
-                return None
-            rec = recs[0]
+        if not self.sub_records:
+            return None
+        head, _, tail = path.partition('/')
+        for rec in self.sub_records:
+            if rec.tag != head:
+                continue
+            # dereference pointers if needed
             if follow and isinstance(rec, Pointer):
                 rec = rec.ref
-        return rec
+            if rec is not None:
+                if tail:
+                    # recurse
+                    sub_tag = rec.sub_tag(tail, follow=follow)
+                    if sub_tag:
+                        return sub_tag
+                else:
+                    return rec
+        return None
 
     def sub_tag_value(self, path, follow=True):
         """Returns value of a direct sub-record.
 
-        Works as :py:meth:`sub_tag` but returns value of a sub-record
-        instead of sub-record itself.
+        Works as `sub_tag()` but returns value of a sub-record instead of
+        sub-record itself.
 
-        :param str path: tag names separated by slashes.
-        :param boolean follow: If True then resolve pointers.
-        :return: String or `None` if sub-record with a given
-            tag does not exist.
+        Parameters
+        ----------
+        path : `str`
+            One or more tag names separated by slashes.
+        follow : `bool`
+            If True then resolve pointers.
+
+        Returns
+        -------
+        value : `object`
+            Subordinate record value or `None` if sub-record with a given tag
+            does not exist.
         """
         rec = self.sub_tag(path, follow)
         if rec:
             return rec.value
         return None
 
-    def sub_tags(self, *tags, **kw):
+    def sub_tags(self, *tags, follow=True):
         """Returns list of immediate sub-records matching any tag name.
 
-        Unlike :py:meth:`sub_tag` method this method does not support
+        Unlike `sub_tag` method this method does not support
         hierarchical paths. It resolves pointer records if ``follow``
         keyword argument is ``True`` (default).
 
-        :param str tags: Names of the sub-record tag
-        :param kw: Keyword arguments, only recognized keyword is `follow`
-            with the same meaning as in :py:meth:`sub_tag`.
-        :return: List of `Records`, possibly empty.
+        Parameters
+        ----------
+        *tags : `str`
+            Names of the sub-record tag
+        follow : `bool`, optional
+            If True then resolve pointers.
+
+        Returns
+        -------
+        records : `list` [ `Record` ]
+            List of records, possibly empty.
         """
         records = [x for x in self.sub_records if x.tag in tags]
-        if kw.get('follow', True):
+        if follow:
             records = [rec.ref if isinstance(rec, Pointer) else rec
                        for rec in records]
         return records
@@ -170,7 +237,7 @@ class Record(object):
 
     def __str__(self):
         value = self.value
-        if isinstance(value, (type(""), type(u""))) and len(value) > 32:
+        if isinstance(value, str) and len(value) > 32:
             value = value[:32] + "..."
         n_sub = 0 if self.sub_records is None else len(self.sub_records)
         if self.xref_id:
@@ -186,19 +253,25 @@ class Record(object):
 
 
 class Pointer(Record):
-    """Sub-class of :py:class:`Record` representing a pointer to a record in
+    """Sub-class of `Record` representing a pointer to a record in
     a GEDCOM file.
 
     This class wraps a GEDCOM pointer value and adds a ``ref`` property which
     retrieves pointed object. Instance of this class will be used in place of
     the GEDCOM pointers in the objects created by parser.
 
-    :param parser: Instance of `GedcomReader` class.
+    Parameters
+    ----------
+    parser : `ged4py.parser.GedcomReader`
+        Instance of parser class.
 
-    :ivar str value: Value of the GEDCOM pointer (e.g. "@I1234@")
-    :ivar Record ref: Pointed GEDCOM record
+    Attributes
+    ----------
+    value : `str`
+        Value of the GEDCOM pointer (e.g. "@I1234@")
+    ref : `Record`
+        Referenced GEDCOM record.
     """
-
     def __init__(self, parser):
         Record.__init__(self)
         self.parser = parser
@@ -216,7 +289,7 @@ class Pointer(Record):
 
 
 class NameRec(Record):
-    """Sub-class of :py:class:`Record` representing the NAME record.
+    """Sub-class of `Record` representing the NAME record.
 
     This class adds an additional method for determining type of the name.
     It also redefines the type of the `value` attribute, it's type is tuple.
@@ -234,7 +307,7 @@ class NameRec(Record):
         ("", "", "")                             # empty NAME record
 
     Client code usually does not need to create instances of this class
-    directly, :py:meth:`make_record` should be used instead.
+    directly, `make_record()` should be used instead.
     """
 
     def __init__(self):
@@ -243,16 +316,19 @@ class NameRec(Record):
     def freeze(self):
         """Method called by parser when updates to this record finish.
 
-        :return: self
+        Returns
+        -------
+        self : `NameRec`
+            Finalized record instance.
         """
         # None is the same as empty string
         if self.value is None:
             self.value = ""
-        if self.dialect in [DIALECT_ALTREE]:
+        if self.dialect in [Dialect.ALTREE]:
             name_tuple = parse_name_altree(self)
-        elif self.dialect in [DIALECT_MYHERITAGE]:
+        elif self.dialect in [Dialect.MYHERITAGE]:
             name_tuple = parse_name_myher(self)
-        elif self.dialect in [DIALECT_ANCESTRIS]:
+        elif self.dialect in [Dialect.ANCESTRIS]:
             name_tuple = parse_name_ancestris(self)
         else:
             name_tuple = split_name(self.value)
@@ -273,9 +349,18 @@ class NameRec(Record):
         return Record.__str__(self)
 
 
-class Name(object):
+class Name:
     """Class representing "summary" of person names.
 
+    Parameters
+    ----------
+    names : `list` [ `NameRec` ]
+        List of NAME records (`NameRec` instances).
+    dialect : `Dialect`
+        One of `Dialect` enums.
+
+    Notes
+    -----
     Person in GEDCOM can have multiple NAME records, e.g. "aka" name,
     "maiden" name, etc. This class provides simple interface for selecting
     "best" name from all existing names. The algorithm for choosing best
@@ -287,9 +372,6 @@ class Name(object):
     - If there are multiple NAME records then the first record without TYPE
       sub-record is used, or if all records have TYPE sub-records then first
       NAME record is used.
-
-    :param list names: List of NAME records (:py:class:`NameRec` instances).
-    :param dialect: One of ``DIALECT_*`` constants.
     """
 
     def __init__(self, names, dialect):
@@ -300,7 +382,7 @@ class Name(object):
         if len(names) == 0:
             # make fake name record to simplify logic below
             self._primary = make_record(0, '', "NAME", "",
-                                        [], 0, DIALECT_DEFAULT).freeze()
+                                        [], 0, Dialect.DEFAULT).freeze()
         elif len(names) == 1:
             self._primary = names[0]
         else:
@@ -313,12 +395,12 @@ class Name(object):
 
     @property
     def surname(self):
-        """Person surname (``str``)"""
+        """Person surname (`str`)"""
         return self._primary.value[1]
 
     @property
     def given(self):
-        """Given name could include both first and middle name (``str``)"""
+        """Given name could include both first and middle name (`str`)"""
         if self._primary.value[0] and self._primary.value[2]:
             return self._primary.value[0] + ' ' + self._primary.value[2]
         return self._primary.value[0] or self._primary.value[2]
@@ -333,8 +415,8 @@ class Name(object):
 
     @property
     def maiden(self):
-        """Maiden last name, can be None (``str``)"""
-        if self._dialect == DIALECT_DEFAULT:
+        """Maiden last name, can be ``None`` (`str`)"""
+        if self._dialect == Dialect.DEFAULT:
             # for default/unknown dialect try "maiden" name record first
             for name in self._names:
                 if name.type == "maiden":
@@ -345,19 +427,26 @@ class Name(object):
         return None
 
     def order(self, order):
-        """Returns name order key.
+        """Return name order key.
 
         Returns tuple with two strings that can be compared to other such
         tuple obtained from different name. Note that if you want
         locale-dependent ordering then you need to compare strings using
         locale-aware method (e.g. ``locale.strxfrm``).
 
-        :param order: One of the ``ORDER_*`` constants.
-        :returns: tuple of two strings
+        Parameters
+        ----------
+        order : `NameOrder`
+            One of the `NameOrder` enums.
+
+        Returns
+        -------
+        order : `tuple` [ `str` ]
+            Tuple of two strings.
         """
         given = self.given
         surname = self.surname
-        if order in (ORDER_MAIDEN_GIVEN, ORDER_GIVEN_MAIDEN):
+        if order in (NameOrder.MAIDEN_GIVEN, NameOrder.GIVEN_MAIDEN):
             surname = self.maiden or self.surname
 
         # We are collating empty names to come after non-empty,
@@ -365,9 +454,9 @@ class Name(object):
         given = ("1" + given) if given else "2"
         surname = ("1" + surname) if surname else "2"
 
-        if order in (ORDER_SURNAME_GIVEN, ORDER_MAIDEN_GIVEN):
+        if order in (NameOrder.SURNAME_GIVEN, NameOrder.MAIDEN_GIVEN):
             return (surname, given)
-        elif order in (ORDER_GIVEN_SURNAME, ORDER_GIVEN_MAIDEN):
+        elif order in (NameOrder.GIVEN_SURNAME, NameOrder.GIVEN_MAIDEN):
             return (given, surname)
         else:
             raise ValueError("unexpected order: {}".format(order))
@@ -378,7 +467,10 @@ class Name(object):
         There is no single correct way to represent name, values returned from
         this method are only useful in limited context, e.g. for logging.
 
-        :return: Formatted name representation.
+        Returns
+        -------
+        name : `str`
+            Formatted name representation.
         """
         name = self._primary.value[0]
         if self.surname:
@@ -397,10 +489,10 @@ class Name(object):
 
 
 class Date(Record):
-    """Sub-class of :py:class:`Record` representing the DATE record.
+    """Sub-class of `Record` representing the DATE record.
 
     After `freeze()` method is called by parser the `value` attribute contains
-    instance of :py:class:`ged4py.date.DateValue` class.
+    instance of `ged4py.date.DateValue` class.
     """
     def __init__(self):
         Record.__init__(self)
@@ -408,21 +500,24 @@ class Date(Record):
     def freeze(self):
         """Method called by parser when updates to this record finish.
 
-        :return: self
+        Returns
+        -------
+        self : `Date`
+            Finalized record instance.
         """
         self.value = DateValue.parse(self.value)
         return self
 
 
 class Individual(Record):
-    """Sub-class of :py:class:`Record` representing the INDI record.
+    """Sub-class of `Record` representing the INDI record.
 
     INDI record represents a single person in GEDCOM. This class defines
     few methods that are useful shortcuts for accessing person information,
     such as navigation to parent records, name, etc.
 
     Client code usually does not need to create instances of this class
-    directly, :py:meth:`make_record` should be used instead.
+    directly, `make_record()` should be used instead.
     """
     def __init__(self):
         Record.__init__(self)
@@ -431,14 +526,14 @@ class Individual(Record):
 
     @property
     def name(self):
-        """:py:class:`Name` instance.
+        """Person name (`Name`).
         """
         # +1 <<PERSONAL_NAME_STRUCTURE>> {0:M}
         return Name(self.sub_tags("NAME"), self.dialect)
 
     @property
     def sex(self):
-        """Person sex, "M", "F", or "U"."""
+        """Person sex, one of "M", "F", or "U" for unknown (`str`)."""
         # +1 SEX <SEX_VALUE>
         sex_rec = self.sub_tag("SEX")
         if sex_rec:
@@ -447,14 +542,14 @@ class Individual(Record):
 
     @property
     def mother(self):
-        """Parent of this individual (:py:class:`Individual` or ``None``)"""
+        """Parent of this individual (`Individual` or ``None``)"""
         if self._mother == []:
             self._mother = self.sub_tag("FAMC/WIFE")
         return self._mother
 
     @property
     def father(self):
-        """Parent of this individual (:py:class:`Individual` or ``None``)"""
+        """Parent of this individual (`Individual` or ``None``)"""
         if self._father == []:
             self._father = self.sub_tag("FAMC/HUSB")
         return self._father
@@ -468,36 +563,51 @@ _tag_class = dict(INDI=Individual,
 
 def make_record(level, xref_id, tag, value, sub_records, offset, dialect,
                 parser=None):
-    """Create Record instance based on parameters.
+    """Create `Record` instance based on parameters.
 
-    :param int level: Record level number.
-    :param str xref_id: Record reference ID, possibly empty.
-    :param str tag: Tag name.
-    :param value: Record value, possibly empty. Value can be None, bytes, or
-        string object, if it is bytes then it should be decoded into strings
-        before calling freeze(), this is normally done by the parser which
-        knows about encodings.
-    :param list sub_records: Initial list of subordinate records,
-        possibly empty. List can be updated later.
-    :param int offset: Record location in a file.
-    :param dialect: One of ``DIALECT_*`` constants.
-    :param parser: Instance of :py:class:`~ged4py.parser.GedcomReader` class,
-        only needed for records whose value is a pointer.
-    :return: Instance of :py:class:`Record` (or one of its subclasses).
+    Parameters
+    ----------
+    level : `int`
+        Record level number.
+    xref_id : `str`
+        Record reference ID, possibly empty.
+    tag : `str`
+        Tag name.
+    value : `str`
+        Record value, possibly empty. Value can be ``None``, bytes, or string
+        object, if it is bytes then it should be decoded into strings before
+        calling freeze(), this is normally done by the parser which knows
+        about encodings.
+    sub_records : `list` [ `Record` ]
+        Initial list of subordinate records, possibly empty. List can be
+        updated later.
+    offset : `int`
+        Record location in a file.
+    dialect : `Dialect`
+        One of `Dialect` enums.
+    parser : `~ged4py.parser.GedcomReader`
+        Parser instance, only needed for pointer records.
 
+    Returns
+    -------
+    record : `Record`
+        Instance of `Record` (or one of its subclasses).
+
+    Notes
+    -----
     This is the factory method for record instances, it can create different
     types of record based on tag of value:
 
-        - if value has a pointer form (``@ref_id@``) then :py:class:`Pointer`
+        - if value has a pointer form (``@ref_id@``) then `Pointer`
           instance is created
-        - if tag is "INDI" then :py:class:`Individual` instance is created
-        - if tag is "NAME" then :py:class:`NameRec` instance is created
-        - if tag is "DATE" then :py:class:`Date` instance is created
-        - otherwise  :py:class:`Record` instance is created
+        - if tag is "INDI" then `Individual` instance is created
+        - if tag is "NAME" then `NameRec` instance is created
+        - if tag is "DATE" then `Date` instance is created
+        - otherwise  `Record` instance is created
 
     Returned record is not complete, it could be updated by parser. When
-    parser finishes updates it calls :py:meth:`Record.freeze` method to
-    finalize record construction.
+    parser finishes updates it calls `Record.freeze()` method to finalize
+    record construction.
     """
     # value can be bytes or string so we check for both, 64 is code for '@'
     if value and len(value) > 2 and \
