@@ -1,17 +1,14 @@
 """Module containing methods for parsing GEDCOM files.
 """
 
-
-from __future__ import print_function, absolute_import, division
-
 __all__ = ['GedcomReader', 'ParserError', 'CodecError', 'IntegrityError',
-           'guess_codec']
+           'guess_codec', 'GedcomLine']
 
 import codecs
-import collections
 import io
 import logging
 import re
+from typing import NamedTuple
 
 from .detail.io import check_bom, guess_lineno, BinaryFileCR
 from . import model
@@ -19,7 +16,7 @@ from . import model
 _log = logging.getLogger(__name__)
 
 # records are bytes, regex is for bytes too
-_re_gedcom_line = re.compile(br"""
+_re_GedcomLine = re.compile(br"""
         ^
         [ ]*(?P<level>\d+)                       # integer level number
         (?:[ ]*(?P<xref>@[A-Z-a-z0-9][^@]*@))?    # optional @xref@
@@ -28,14 +25,37 @@ _re_gedcom_line = re.compile(br"""
         $
 """, re.X)
 
-# tuple class for gedcom_line grammar:
-#   level: int
-#   xref_id: str, possibly empty or None
-#   tag: str, required, non-empty
-#   value: bytes, possibly empty or None
-#   offset: int
-gedcom_line = collections.namedtuple("gedcom_line",
-                                     "level xref_id tag value offset")
+
+class GedcomLine(NamedTuple):
+    """Class representing single line in a GEDCOM file.
+
+    .. note::
+
+        Mostly for internal use by parser, most clients do not need to know
+        about this class.
+
+    Attributes
+    ----------
+    level : `int`
+    xref_id : `str`, possibly empty or ``None``
+    tag : `str`, required, non-empty
+    value : `bytes`, possibly empty or ``None``
+    offset : `int`
+    """
+    level: int
+    """Record level number (`int`)"""
+
+    xref_id: str
+    """Reference for this record (`str` or ``None``)"""
+
+    tag: str
+    """Tag name (`str`)"""
+
+    value: bytes
+    """Record value (`bytes`)"""
+
+    offset: int
+    """Record offset in a file (`int`)"""
 
 
 class ParserError(Exception):
@@ -66,19 +86,36 @@ def guess_codec(file, errors="strict", require_char=False, warn=True):
     is extracted from it, if BOM record is present then CHAR record
     must match BOM-defined encoding.
 
-    :param file: File object, must be open in binary mode.
-    :param str errors: Controls error handling behavior during string
-        decoding, accepts same values as standard `codecs.decode` method.
-    :param bool require_char: If True then exception is thrown if CHAR
-        record is not found in a header, if False and CHAR is not in the
-        header then codec determined from BOM or "gedcom" is returned.
-    :param bool warn: If True (default) then generate error/warning messages
-        for illegal encodings.
-    :returns: Tuple (codec_name, bom_size)
-    :raises: :py:class:`CodecError` when codec name in file is unknown or
-        when codec name in file contradicts codec determined from BOM.
-    :raises: :py:class:`UnicodeDecodeError` when codec fails to decode
-        input lines and `errors` is set to "strict" (default).
+    Parameters
+    ----------
+    file
+        File object, must be open in binary mode.
+    errors : `str`, optional
+        Controls error handling behavior during string decoding, accepts same
+        values as standard `codecs.decode` method.
+    require_char : `bool`, optional
+        If ``True`` then exception is thrown if CHAR record is not found in a
+        header, if False and CHAR is not in the header then codec determined
+        from BOM or "gedcom" is returned.
+    warn : `bool`, optional
+        If True (default) then generate error/warning messages for illegal
+        encodings.
+
+    Returns
+    -------
+    codec_name : `str`
+        The name of the codec in this file.
+    bom_size : `int`
+        Size of the BOM record, 0 if no BOM record.
+
+    Raises
+    ------
+    CodecError
+        Raised if codec name in file is unknown or when codec name in file
+        contradicts codec determined from BOM.
+    UnicodeDecodeError
+        Raised if codec fails to decode input lines and `errors` is set to
+        "strict" (default).
     """
 
     # set of illegal but unambiguous encodings and their corresponding codecs
@@ -165,29 +202,34 @@ def guess_codec(file, errors="strict", require_char=False, warn=True):
     return codec, bom_size
 
 
-class GedcomReader(object):
+class GedcomReader:
     """Main interface for reading GEDCOM files.
 
-    :param file: File name or file object open in binary mode, file must
-        be seekable.
-    :param str encoding: If None (default) then file is analyzed using
-        `guess_codec()` method to determine correct codec. Otherwise
-        file is open using specified codec.
-    :param str errors: Controls error handling behavior during string
-        decoding, accepts same values as standard `codecs.decode` method.
-    :param bool require_char: If True then exception is thrown if CHAR
-        record is not found in a header, if False and CHAR is not in the
-        header then codec determined from BOM or "gedcom" is used.
-
+    Parameters
+    ----------
+    file
+        File name or file object open in binary mode, file must be seekable.
+    encoding : `str`, optional
+        If ``None`` (default) then file is analyzed using `guess_codec()`
+        method to determine correct codec. Otherwise file is open using
+        specified codec.
+    errors : `str`, optional
+        Controls error handling behavior during string decoding, accepts same
+        values as standard `codecs.decode` method.
+    require_char : `bool`, optional
+        If True then exception is thrown if CHAR record is not found in a
+        header, if False and CHAR is not in the header then codec determined
+        from BOM or "gedcom" is used.
 
+    Notes
+    -----
     Instance of this class is used to read and parse single GEDCOM file.
-    Records in GEDCOM file are transformed into instances of types defined
-    in :py:mod:`ged4py.model` module, either :py:class:`ged4py.model.Record`
-    class or one of its sub-classes. Main method of access to the data in
-    the file is by iterating over level-0 records, optionally restricted by
-    the tag name. The method which does this is
-    :py:meth:`GedcomReader.records0`. Most commonly the code which reads
-    GEDCOM file at the top-level loop will look like this::
+    Records in GEDCOM file are transformed into instances of types defined in
+    `ged4py.model` module, either `ged4py.model.Record` class or one of its
+    sub-classes. Main method of access to the data in the file is by iterating
+    over level-0 records, optionally restricted by the tag name. The method
+    which does this is `GedcomReader.records0()`. Most commonly the code which
+    reads GEDCOM file at the top-level loop will look like this::
 
         with GedcomReader(path) as parser:
             # iterate over each INDI record in a file
@@ -234,7 +276,7 @@ class GedcomReader(object):
 
     @property
     def index0(self):
-        """List of level=0 record positions and tag names (``list[(int, str)]``).
+        """List of level=0 record positions and tag names (`list[(int, str)]`).
         """
         if self._index0 is None:
             self._init_index()
@@ -243,7 +285,7 @@ class GedcomReader(object):
     @property
     def xref0(self):
         """Dictionary which maps xref_id to level=0 record position and
-        tag name (``dict[str, (int, str)]``).
+        tag name (`dict[str, (int, str)]`).
         """
         if self._xref0 is None:
             self._init_index()
@@ -251,7 +293,7 @@ class GedcomReader(object):
 
     @property
     def header(self):
-        """Header record (:py:class:`ged4py.model.Record`).
+        """Header record (`ged4py.model.Record`).
         """
         if self._index0 is None:
             self._init_index()
@@ -262,7 +304,7 @@ class GedcomReader(object):
         self._index0 = []
         self._xref0 = {}
         # scan whole file for level=0 records
-        for gline in self.gedcom_lines(self._bom_size):
+        for gline in self.GedcomLines(self._bom_size):
             _log.debug("  _init_index gline: %s", gline)
             if gline.level == 0:
                 self._index0.append((gline.offset, gline.tag))
@@ -275,28 +317,45 @@ class GedcomReader(object):
 
     @property
     def dialect(self):
-        """File dialect as one of ``model.DIALECT_*`` constants.
+        """File dialect as one of `ged4py.model.Dialect` enums.
         """
         if self._dialect is None:
-            self._dialect = model.DIALECT_DEFAULT
+            self._dialect = model.Dialect.DEFAULT
             if self.header:
                 source = self.header.sub_tag("SOUR")
                 if source:
                     if source.value == "MYHERITAGE":
-                        self._dialect = model.DIALECT_MYHERITAGE
+                        self._dialect = model.Dialect.MYHERITAGE
                     elif source.value in ("ALTREE", "AgelongTree"):
-                        self._dialect = model.DIALECT_ALTREE
+                        self._dialect = model.Dialect.ALTREE
                     elif source.value == "ANCESTRIS":
-                        self._dialect = model.DIALECT_ANCESTRIS
+                        self._dialect = model.Dialect.ANCESTRIS
         return self._dialect
 
     @dialect.setter
     def dialect(self, value):
         self._dialect = value
 
-    def gedcom_lines(self, offset):
+    def GedcomLines(self, offset):
         """Generator method for *gedcom lines*.
 
+        Parameters
+        ----------
+        offset : `int`
+            Position in the file to start reading.
+
+        Yields
+        ------
+        line : `GedcomLine`
+            An object representing one line of GEDCOM file.
+
+        Raises
+        ------
+        ParserError
+            Raised if lines have incorrect syntax.
+
+        Notes
+        -----
         GEDCOM line grammar is defined in Chapter 1 of GEDCOM standard, it
         consists of the level number, optional reference ID, tag name, and
         optional value separated by spaces. Chaper 1 is pure grammar level,
@@ -305,13 +364,8 @@ class GedcomReader(object):
         returning the lines in their order in file.
 
         This method iterates over all lines in input file and converts each
-        line into :py:class:`gedcom_line` class. It is an implementation
-        detail used by other methods, most clients will not need to use this
-        method.
-
-        :param int offset: Position in the file to start reading.
-        :returns: Iterator for gedcom_lines.
-        :raises: :py:class:`ParserError` when lines have incorrect syntax.
+        line into `GedcomLine` class. It is an implementation detail used by
+        other methods, most clients will not need to use this method.
         """
 
         self._file.seek(offset)
@@ -325,7 +379,7 @@ class GedcomReader(object):
                 break
             line = line.lstrip().rstrip(b"\r\n")
 
-            match = _re_gedcom_line.match(line)
+            match = _re_GedcomLine.match(line)
             if not match:
                 self._file.seek(offset)
                 lineno = guess_lineno(self._file)
@@ -363,11 +417,11 @@ class GedcomReader(object):
                                              "CONC/CONT nesting at line "
                                              "{0}: `{1}'".format(lineno, line))
 
-            gline = gedcom_line(level=level,
-                                xref_id=xref_id,
-                                tag=tag,
-                                value=match.group('value'),
-                                offset=offset)
+            gline = GedcomLine(level=level,
+                               xref_id=xref_id,
+                               tag=tag,
+                               value=match.group('value'),
+                               offset=offset)
             yield gline
 
             prev_gline = gline
@@ -377,12 +431,18 @@ class GedcomReader(object):
 
         This is the main method of this class. Clients access data in GEDCOM
         files by iterating over level=0 records and then navigating to
-        sub-records using the methods of the :py:class:`~ged4py.model.Record`
-        class.
+        sub-records using the methods of the `~ged4py.model.Record` class.
 
-        :param str tag: If tag is ``None`` (default) then return all level=0
-            records, otherwise return level=0 records with the given tag.
-        :return: Iterator for :py:class:`~ged4py.model.Record` instances.
+        Parameters
+        ----------
+        tag : `str`, optional
+            If tag is ``None`` (default) then return all level=0 records,
+            otherwise return level=0 records with the given tag.
+
+        Yields
+        ------
+        record : `~ged4py.model.Record`
+            Instances of `~ged4py.model.Record` or its subclasses.
         """
         _log.debug("in records0")
         for offset, xtag in self.index0:
@@ -400,16 +460,26 @@ class GedcomReader(object):
 
         This is mostly for internal use, regular clients don't need to use it.
 
-        :param int offset: Position in file to start reading from.
-        :return: :py:class:`model.Record` instance or None if offset points
-            past EOF.
-        :raises: :py:exc:`ParserError` if `offsets` does not point to the
-            beginning of a record or for any parsing errors.
+        Parameters
+        ----------
+        offset : `int`
+            Position in the file to start reading.
+
+        Returns
+        -------
+        record : `~ged4py.model.Record` or ``None``
+            `model.Record` instance or None if offset points past EOF.
+
+        Raises
+        ------
+        ParserError
+            Raised if `offsets` does not point to the beginning of a record or
+            for any parsing errors.
         """
         _log.debug("in read_record(%s)", offset)
         stack = []  # stores per-level current records
         reclevel = None
-        for gline in self.gedcom_lines(offset):
+        for gline in self.GedcomLines(offset):
             _log.debug("    read_record, gline: %s", gline)
             level = gline.level
 
@@ -463,14 +533,14 @@ class GedcomReader(object):
 
         Parameters
         ----------
-        parent : `model.Record`
+        parent : `ged4py.model.Record`
             Parent record of the new record
-        gline : `gedcom_line`
+        gline : `GedcomLine`
             Current parsed line
 
         Returns
         -------
-        `model.Record` or None
+        record : `ged4py.model.Record` or None
         """
 
         if parent and gline.tag in ("CONT", "CONC"):
@@ -485,7 +555,7 @@ class GedcomReader(object):
             return None
 
         # avoid infinite cycle
-        dialect = model.DIALECT_DEFAULT
+        dialect = model.Dialect.DEFAULT
         if not (gline.level == 0 and gline.tag == "HEAD") and self._header:
             dialect = self.dialect
         rec = model.make_record(level=gline.level, xref_id=gline.xref_id,
